==> haskell-data-accessor-template-0.2.1.14-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.14
id: data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf
key: data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: 8b53fd8c6bfcb5d938b2a5e60a56374f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-accessor-template-0.2.1.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-accessor-template-0.2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-accessor-template-0.2.1.14
hs-libraries: HSdata-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf
depends:
    base-4.10.1.0 data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H
    template-haskell-2.12.0.0 utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H=69f7b4517dfcc0e49f92b8cf9762b41d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-template-0.2.1.15-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.15
id: data-accessor-template-0.2.1.15-5a8icsu7tPIJT5d7iPeArP
key: data-accessor-template-0.2.1.15-5a8icsu7tPIJT5d7iPeArP
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: 6852c290bc459817175fc2e15ed16614
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-accessor-template-0.2.1.15
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-accessor-template-0.2.1.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-accessor-template-0.2.1.15
hs-libraries: HSdata-accessor-template-0.2.1.15-5a8icsu7tPIJT5d7iPeArP
depends:
    base-4.10.1.0 data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H
    template-haskell-2.12.0.0 utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H=69f7b4517dfcc0e49f92b8cf9762b41d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
